@@ -768,7 +768,7 @@ class EEDI3(SuperSampler):
         if self.vthresh is None:
             self.vthresh = (None, None, None)
 
-        kwargs = {
+        return {
             "alpha": self.alpha,
             "beta": self.beta,
             "gamma": self.gamma,
@@ -784,11 +784,6 @@ class EEDI3(SuperSampler):
             "mclip": self.mclip,
         } | kwargs
 
-        if kwargs.get("opt") is None:
-            kwargs["opt"] = 2 if kwargs["mclip"] else 3
-
-        return kwargs
-
     @Scaler.cachedproperty
     def kernel_radius(self) -> int:
         return self.mdis
@@ -940,9 +935,13 @@ class SuperSamplerProcess(
 
         processed = self.function(ss_clip)
 
-        return self._others[0].scale(
-            processed,
-            clip.width,
-            clip.height,
-            tuple([round(s - 1e-6) for s in dim_shifts] for dim_shifts in reversed(self._ss_shifts)),  # type: ignore[return-value, arg-type]
+        return (
+            self._others[0]
+            .scale(
+                processed,
+                clip.width,
+                clip.height,
+                tuple([round(s - 1e-6) for s in dim_shifts] for dim_shifts in reversed(self._ss_shifts)),  # type: ignore[return-value, arg-type]
+            )
+            .std.CopyFrameProps(processed)
         )
