@@ -9,14 +9,15 @@ from typing import Any, Callable, ClassVar, Concatenate, Sequence
 from vsaa import EEDI3, NNEDI3, SangNom
 from vsexprtools import ExprOp, norm_expr
 from vskernels import Catrom, Kernel, KernelLike, Point, Scaler, ScalerLike
-from vsrgtools import box_blur, gauss_blur, limit_filter
+from vsrgtools import box_blur, gauss_blur
 from vsscale import ScalingArgs
 from vstools import (
+    core,
     P1,
     CustomIntEnum,
     CustomOverflowError,
     CustomStrEnum,
-    FuncExceptT,
+    FuncExcept,
     InvalidColorFamilyError,
     InvalidSubsamplingError,
     P,
@@ -46,7 +47,7 @@ __all__ = [
 ]
 
 
-class _CachedBlurs(vs_object, dict[int, list[tuple[vs.VideoNode, vs.VideoNode]]]):
+class _CachedBlurs(dict[int, list[tuple[vs.VideoNode, vs.VideoNode]]], vs_object):
     def __vs_del__(self, core_id: int) -> None:
         self.clear()
 
@@ -405,7 +406,7 @@ class ReconOutput(CustomIntEnum):
     """
 
     @classmethod
-    def from_param(cls, value: int | ReconOutput | bool | None, func_except: FuncExceptT | None = None) -> ReconOutput:
+    def from_param(cls, value: int | ReconOutput | bool | None, func_except: FuncExcept | None = None) -> ReconOutput:
         if isinstance(value, bool):
             value = 1 + int(value)
         elif value is None:
@@ -545,7 +546,7 @@ class ChromaReconstruct(ABC):
         return 0.5 * c_width / y_width
 
     def _get_bases(
-        self, clip: vs.VideoNode, include_edges: bool, func: FuncExceptT
+        self, clip: vs.VideoNode, include_edges: bool, func: FuncExcept
     ) -> tuple[vs.VideoNode, vs.VideoNode, vs.VideoNode, vs.VideoNode, Sequence[vs.VideoNode], Sequence[vs.VideoNode]]:
         InvalidColorFamilyError.check(clip, vs.YUV, func)
 
@@ -626,9 +627,7 @@ class ChromaReconstruct(ABC):
 
         y_diff = norm_expr((y_base, y_dm), "x y -", func=self.reconstruct)
 
-        y_diffxb = gauss_blur(
-            norm_expr((y_base, y_dm), f"x y / {reg.eps} 1 clamp"), diff_mode.diff_sigma, func=self.reconstruct
-        )
+        y_diffxb = gauss_blur(norm_expr((y_base, y_dm), f"x y / {reg.eps} 1 clamp"), diff_mode.diff_sigma)
 
         fixup = (
             y_diff.recon.Reconstruct(  # type: ignore
@@ -752,7 +751,7 @@ class MissingFieldsChromaRecon(GenericChromaRecon):
         super().__post_init__()
 
         self._dm_wscaler = Scaler.ensure_obj(self.dm_wscaler, self.__class__)
-        self._dm_hscaler = self._dm_wscaler.ensure_obj(self.dm_hscaler, self.__class__)
+        self._dm_hscaler = Scaler.ensure_obj(self.dm_hscaler or self._dm_wscaler, self.__class__)
 
 
 @dataclass
@@ -800,7 +799,7 @@ class PAWorksChromaRecon(MissingFieldsChromaRecon):
         return y_m
 
     def demangle_chroma(self, mangled: vs.VideoNode, y_base: vs.VideoNode) -> vs.VideoNode:
-        demangled = vs.core.resize.Point(mangled, y_base.width // 2, mangled.height)
+        demangled = core.resize.Point(mangled, y_base.width // 2, mangled.height)
 
         demangled = self._dm_wscaler.scale(demangled, mangled.width, y_base.height, (self.src_top, 0))
         demangled = self._dm_hscaler.scale(demangled, y_base.width, y_base.height, (0, self.src_left))
@@ -812,7 +811,7 @@ class PAWorksChromaRecon(MissingFieldsChromaRecon):
 
         y_base = self._kernel.shift(y_base, self.src_top, self.src_left)
 
-        return limit_filter(a, y_base, a, dark_thr=1, bright_thr=10, elast=4.5)
+        return core.vszip.LimitFilter(a, y_base, a, dark_thr=1, bright_thr=10, elast=4.5)
 
     @inject_self.init_kwargs
     def reconstruct(
@@ -836,13 +835,12 @@ class Point422ChromaRecon(MissingFieldsChromaRecon):
     """
 
     dm_wscaler: ScalerLike = field(default_factory=lambda: SangNom(128))
-    dm_hscaler: ScalerLike = field(
-        # sclip=NNEDI3() didn't work before and has not been re-implemented either
-        default_factory=lambda: EEDI3(0.35, 0.55, 20, 2, 10, vcheck=3, sclip=NNEDI3())  # type: ignore
-    )
+    dm_hscaler: EEDI3 = field(default_factory=lambda: EEDI3(0.35, 0.55, 20, 2, 10, vcheck=3))
 
     def demangle_chroma(self, mangled: vs.VideoNode, y_base: vs.VideoNode) -> vs.VideoNode:
-        demangled = self._dm_hscaler.scale(mangled, mangled.width, y_base.height)
+        demangled = self._dm_hscaler.scale(
+            mangled, mangled.width, y_base.height, sclip=NNEDI3().scale(mangled, height=mangled.height * 2)
+        )
         return self._dm_wscaler.scale(demangled, y_base.width, y_base.height, (self.src_top, self.src_left))
 
     @inject_self.init_kwargs
