@@ -4,7 +4,7 @@ import warnings
 from enum import EnumMeta
 from functools import cache
 from inspect import currentframe
-from itertools import cycle, product
+from itertools import product
 from math import inf, isqrt
 from typing import Any, Collection, Iterable, Iterator, Literal, Sequence, SupportsIndex, cast, overload
 
@@ -13,6 +13,7 @@ from typing_extensions import Self
 
 from vstools import (
     ColorRange,
+    ColorRangeLike,
     ConstantFormatVideoNode,
     ConvMode,
     CustomIndexError,
@@ -102,7 +103,7 @@ class ExprToken(CustomStrEnum, metaclass=_ExprTokenMeta):
     """Maximum value in mask clips."""
 
     Neutral = "neutral"
-    """Neutral value (e.g. 128 for 8-bit limited, 0 for float)."""
+    """Neutral value for chroma & MakeDiff/MergeDiff (e.g. 128 for 8-bit, 0 for float)."""
 
     RangeMin = "range_min"
     """Minimum value in full range (chroma-aware)."""
@@ -136,7 +137,7 @@ class ExprToken(CustomStrEnum, metaclass=_ExprTokenMeta):
     ChromaRangeInMax = "crange_in_max"
 
     @cache
-    def get_value(self, clip: vs.VideoNode, chroma: bool = False, range_in: ColorRange | None = None) -> float:
+    def get_value(self, clip: vs.VideoNode, chroma: bool = False, range_in: ColorRangeLike | None = None) -> float:
         """
         Resolves the numeric value represented by this token based on the input clip and range.
 
@@ -251,6 +252,9 @@ class ExprToken(CustomStrEnum, metaclass=_ExprTokenMeta):
 
         return f"{self._value_}_{ExprVars.get_var(validate_index(i))}"
 
+    def __str__(self) -> str:
+        return self._value_
+
 
 def _cache_clear_expr_token(core_id: int) -> None:
     def cache_clear() -> None:
@@ -381,7 +385,8 @@ class ExprOpBase(CustomStrEnum):
 
         return self
 
-    __str__ = str.__str__
+    def __str__(self) -> str:
+        return self._value_
 
     @overload
     def __call__(
@@ -454,14 +459,15 @@ class ExprOpBase(CustomStrEnum):
         return self
 
     def __iter__(self) -> Iterator[Self]:
-        return cycle([self])
+        while True:
+            yield self
 
-    def __mul__(self, n: int) -> list[Self]:  # type: ignore[override]
+    def __mul__(self, n: SupportsIndex) -> list[Self]:  # type: ignore[override]
         return [self] * n
 
     def combine(
         self,
-        *clips: vs.VideoNode | Iterable[vs.VideoNode | Iterable[vs.VideoNode]],
+        *clips: VideoNodeIterableT[vs.VideoNode],
         suffix: SupportsString | Iterable[SupportsString] | None = None,
         prefix: SupportsString | Iterable[SupportsString] | None = None,
         expr_suffix: SupportsString | Iterable[SupportsString] | None = None,
@@ -488,6 +494,31 @@ class ExprOpBase(CustomStrEnum):
 
         return combine(clips, self, suffix, prefix, expr_suffix, expr_prefix, planes, **kwargs)
 
+    def combine_expr(
+        self,
+        n: SupportsIndex | Sequence[SupportsString] | HoldsVideoFormat | VideoFormatLike,
+        suffix: SupportsString | Iterable[SupportsString] | None = None,
+        prefix: SupportsString | Iterable[SupportsString] | None = None,
+        expr_suffix: SupportsString | Iterable[SupportsString] | None = None,
+        expr_prefix: SupportsString | Iterable[SupportsString] | None = None,
+    ) -> ExprList:
+        """
+        Combines multiple video clips using the selected expression operator.
+
+        Args:
+            n: Object from which to infer the variables.
+            suffix: Optional suffix string(s) to append to each input variable in the expression.
+            prefix: Optional prefix string(s) to prepend to each input variable in the expression.
+            expr_suffix: Optional expression to append after the combined input expression.
+            expr_prefix: Optional expression to prepend before the combined input expression.
+
+        Returns:
+            A clip representing the combined result of applying the expression.
+        """
+        from .funcs import combine_expr
+
+        return combine_expr(n, self, suffix, prefix, expr_suffix, expr_prefix)
+
 
 class ExprOpExtraMeta(EnumMeta):
     @property
@@ -824,7 +855,7 @@ class ExprOp(ExprOpBase, metaclass=ExprOpExtraMeta):
         """
         match mode:
             case ConvMode.SQUARE:
-                coordinates = list(product(range(-radius, radius + 1), range(-radius, radius + 1)))
+                coordinates = [(x, y) for (y, x) in product(range(-radius, radius + 1), repeat=2)]
             case ConvMode.VERTICAL:
                 coordinates = [(0, y) for y in range(-radius, radius + 1)]
             case ConvMode.HORIZONTAL:
@@ -947,7 +978,7 @@ class ExprOp(ExprOpBase, metaclass=ExprOpExtraMeta):
             if not saturate:
                 out.append(cls.ABS)
 
-            if multiply is not None:
+            if multiply is not None and multiply != 1.0:
                 out.append(multiply, cls.MUL)
 
             if clamp:
@@ -1012,7 +1043,7 @@ class ExprOp(ExprOpBase, metaclass=ExprOpExtraMeta):
         Returns:
             An `ExprList` representing the MAE expression across all planes.
         """
-        planesa, planesb = cls._parse_planes(planesa, planesb, cls.rmse)
+        planesa, planesb = cls._parse_planes(planesa, planesb, cls.mae)
         expr = ExprList()
 
         for a, b in zip(planesa, planesb):
