@@ -26,7 +26,7 @@ from typing import (
 
 from jetpytools import P, R, R_co, classproperty
 from jetpytools import cachedproperty as jetpytools_cachedproperty
-from typing_extensions import Self, deprecated
+from typing_extensions import Self
 
 from vstools import (
     ConstantFormatVideoNode,
@@ -434,7 +434,7 @@ class BaseScaler(vs_object, ABC, metaclass=BaseScalerMeta, abstract=True):
             f"{self.__class__.__name__}" + "(" + ", ".join(f"{k}={v}" for k, v in (attrs | self.kwargs).items()) + ")"
         )
 
-    @BaseScalerMeta.cachedproperty
+    @property
     def pretty_string(self) -> str:
         """
         Cached property returning a user-friendly string representation.
@@ -444,7 +444,7 @@ class BaseScaler(vs_object, ABC, metaclass=BaseScalerMeta, abstract=True):
         """
         return self._pretty_string()
 
-    @classproperty
+    @classproperty.cached
     @classmethod
     def implemented_funcs(cls) -> frozenset[str]:
         """
@@ -477,7 +477,7 @@ class Scaler(BaseScaler):
     scale_function: Callable[..., vs.VideoNode]
     """Scale function called internally when performing scaling operations."""
 
-    _implemented_funcs: ClassVar[tuple[str, ...]] = ("scale", "supersample", "multi")
+    _implemented_funcs: ClassVar[tuple[str, ...]] = ("scale", "supersample")
 
     def scale(
         self,
@@ -544,28 +544,6 @@ class Scaler(BaseScaler):
 
         return self.scale(clip, dst_width, dst_height, shift, **kwargs)  # type: ignore[return-value]
 
-    @deprecated('The "multi" method is deprecated. Use "supersample" instead.', category=DeprecationWarning)
-    def multi(
-        self, clip: VideoNodeT, multi: float = 2.0, shift: tuple[TopShift, LeftShift] = (0, 0), **kwargs: Any
-    ) -> VideoNodeT:
-        """
-        Deprecated alias for `supersample`.
-
-        Keyword arguments passed during initialization are automatically injected here,
-        unless explicitly overridden by the arguments provided at call time.
-        Only arguments that match named parameters in this method are injected.
-
-        Args:
-            clip: The source clip.
-            multi: Supersampling factor.
-            shift: Subpixel shift (top, left) applied during scaling.
-            **kwargs: Additional arguments forwarded to the scale function.
-
-        Returns:
-            The supersampled clip.
-        """
-        return self.supersample(clip, multi, shift, **kwargs)
-
     def get_scale_args(
         self,
         clip: vs.VideoNode,
