@@ -7,7 +7,6 @@ from jetpytools import CustomEnum, CustomNotImplementedError
 from vsexprtools import ExprOp, ExprToken, norm_expr
 from vsrgtools import BlurMatrix, gauss_blur
 from vstools import (
-    ColorRange,
     ConstantFormatVideoNode,
     ConvMode,
     check_variable,
@@ -23,7 +22,7 @@ from vstools import (
 )
 
 from .details import multi_detail_mask
-from .edge import FDoGTCanny, Kirsch, MagDirection, Prewitt, PrewittTCanny
+from .edge import EdgeDetect, EdgeDetectLike, FDoG, Kirsch, Prewitt
 from .morpho import Morpho
 from .spat_funcs import retinex
 from .types import Coordinates, MaskLike
@@ -84,7 +83,7 @@ def luma_mask(clip: vs.VideoNode, thr_lo: float, thr_hi: float, invert: bool = T
 
 
 def luma_credit_mask(
-    clip: vs.VideoNode, thr: float = 0.9, edgemask: MaskLike = FDoGTCanny, draft: bool = False, **kwargs: Any
+    clip: vs.VideoNode, thr: float = 0.9, edgemask: MaskLike = FDoG, draft: bool = False, **kwargs: Any
 ) -> ConstantFormatVideoNode:
     y = plane(clip, 0)
 
@@ -145,9 +144,14 @@ class dre_edgemask(CustomEnum):  # noqa: N801
 
     def _prefilter(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
         if self is dre_edgemask.RETINEX:
-            sigmas = kwargs.get("sigmas", [50, 200, 350])
-
-            return retinex(clip, sigmas, 0.001, 0.005)
+            return retinex(
+                clip,
+                kwargs.pop("sigmas", [50, 200, 350]),
+                kwargs.pop("lower_thr", 0.001),
+                kwargs.pop("lower_thr", 0.005),
+                func=self,
+                **kwargs,
+            )
 
         if self is dre_edgemask.CLAHE:
             limit, tile = kwargs.get("limit", 0.0305), kwargs.get("tile", 5)
@@ -160,18 +164,23 @@ class dre_edgemask(CustomEnum):  # noqa: N801
     def __call__(  # type: ignore[misc]
         self: Literal[dre_edgemask.RETINEX],
         clip: vs.VideoNode,
-        tsigma: float = 1,
+        sigma: float = 1,
         brz: float = 0.122,
+        operator: EdgeDetectLike = Prewitt,
         *,
         sigmas: Sequence[float] = [50, 200, 350],
+        lower_thr: float = 0.001,
+        upper_thr: float = 0.005,
+        **kwargs: Any,
     ) -> ConstantFormatVideoNode: ...
 
     @overload
     def __call__(  # type: ignore[misc]
         self: Literal[dre_edgemask.CLAHE],
         clip: vs.VideoNode,
-        tsigma: float = 1,
+        sigma: float = 1,
         brz: float = 0.122,
+        operator: EdgeDetectLike = Prewitt,
         *,
         limit: float = 0.0305,
         tile: int = 5,
@@ -179,12 +188,22 @@ class dre_edgemask(CustomEnum):  # noqa: N801
 
     @overload
     def __call__(
-        self, clip: vs.VideoNode, tsigma: float = 1, brz: float = 0.122, **kwargs: Any
+        self,
+        clip: vs.VideoNode,
+        sigma: float = 1,
+        brz: float = 0.122,
+        operator: EdgeDetectLike = Prewitt,
+        **kwargs: Any,
     ) -> ConstantFormatVideoNode: ...
 
     def __call__(
-        self, clip: vs.VideoNode, tsigma: float = 1, brz: float = 0.122, **kwargs: Any
-    ) -> ConstantFormatVideoNode:
+        self,
+        clip: vs.VideoNode,
+        sigma: float = 1,
+        brz: float = 0.122,
+        operator: EdgeDetectLike = Prewitt,
+        **kwargs: Any,
+    ) -> vs.VideoNode:
         """
         Creates an edgemask with dynamic range enhancement (DRE) prefiltering.
 
@@ -193,11 +212,19 @@ class dre_edgemask(CustomEnum):  # noqa: N801
 
         Args:
             clip: Source clip.
-            tsigma: Sigma value for TCanny edge detection. Defaults to 1.
+            sigma: Standard deviation of the Gaussian kernel for edge detection. Defaults to 1.
             brz: Binarization threshold (32-bit float scale). Defaults to 0.122.
-            sigmas: Sigma values for the retinex prefilter. Defaults to [50, 200, 350].
-            limit: Limit for CLAHE prefilter. Defaults to 0.0305.
-            tile: Tile size for CLAHE prefilter. Defaults to 5.
+            operator: Edge detect operator.
+            **kwargs: Additional keyword arguments for the selected prefilter:
+
+                   - RETINEX. See [retinex][vsmasktools.retinex] for details:
+                    * `sigmas`: List of Gaussian sigmas for multi-scale retinex (MSR).
+                    * `lower_thr`: Lower threshold percentile for output normalization
+                    * `upper_thr`: Upper threshold percentile for output normalization.
+                   - CLAHE. See [vszip.CLAHE](https://github.com/dnjulek/vapoursynth-zip/wiki/CLAHE) for details.
+                    * `limit`: Threshold for contrast limiting (32-bit float scale, unlike CLAHE plugin).
+                      Defaults to 0.0305.
+                    * `tile`: Tile size for histogram equalization. Defaults to 5.
 
         Returns:
             Edgemask clip with applied DRE prefiltering.
@@ -206,14 +233,15 @@ class dre_edgemask(CustomEnum):  # noqa: N801
 
         dreluma = self._prefilter(luma, **kwargs)
 
-        tcanny = PrewittTCanny.edgemask(dreluma, sigma=tsigma, scale=1)
-        tcanny = Morpho.minimum(tcanny, coords=Coordinates.CORNERS)
+        if sigma:
+            dreluma = gauss_blur(dreluma, sigma)
 
-        kirsch = Kirsch(MagDirection.N | MagDirection.EAST).edgemask(luma)
+        dreluma_edges = EdgeDetect.ensure_obj(operator, self.__class__).edgemask(dreluma)
+        dreluma_edges = Morpho.minimum(dreluma_edges, coords=Coordinates.CORNERS)
 
-        add_clip = ExprOp.ADD(tcanny, kirsch)
+        merge = norm_expr([dreluma_edges, Kirsch.edgemask(luma)], "x y + mask_max min", func=self.__class__)
 
-        if brz > 0:
-            add_clip = Morpho.binarize(add_clip, brz)
+        if brz:
+            return Morpho.binarize(merge, brz)
 
-        return ColorRange.FULL.apply(add_clip)
+        return merge
