@@ -4,9 +4,9 @@ from functools import partial, reduce
 from math import sqrt
 from typing import TYPE_CHECKING, Any, Callable, Generic, Literal, Sequence, Union, overload
 
-from jetpytools import CustomIntEnum, CustomStrEnum, FuncExcept, P, R, cround
+from jetpytools import CustomIntEnum, CustomStrEnum, FuncExcept, P, R, cround, to_arr
 
-from vsexprtools import ExprOp, norm_expr
+from vsexprtools import norm_expr
 from vskernels import Bilinear, Gaussian, Point, Scaler, ScalerLike
 from vstools import (
     ColorRange,
@@ -26,9 +26,11 @@ from vstools import (
     depth,
     expect_bits,
     get_plane_sizes,
+    get_prop,
     join,
     normalize_planes,
     normalize_seq,
+    shift_clip_multi,
     split,
     vs,
 )
@@ -130,10 +132,78 @@ def side_box_blur(clip: vs.VideoNode, radius: int = 1, planes: Planes = None) ->
     )
 
 
+class GaussBlur(Generic[P, R]):
+    """
+    Class decorator that wraps the [gauss_blur][vsrgtools.blur.gauss_blur] function
+    and extends its functionality.
+
+    It is not meant to be used directly.
+    """
+
+    def __init__(self, gauss_blur: Callable[P, R]) -> None:
+        self._func = gauss_blur
+
+    def __call__(self, *args: P.args, **kwargs: P.kwargs) -> R:
+        return self._func(*args, **kwargs)
+
+    @staticmethod
+    def get_sigma(radius: int) -> float:
+        """
+        Generate a Gaussian sigma value from an intuitive radius.
+
+        This is a shortcut that converts a blur radius to a corresponding sigma value.
+
+        Args:
+            radius: Blur radius.
+
+        Returns:
+            Gaussian sigma value
+        """
+        return BlurMatrix.GAUSS.get_sigma(radius)
+
+    @staticmethod
+    def from_radius(
+        clip: vs.VideoNode,
+        radius: int | Sequence[int] = 1,
+        mode: OneDimConvMode | TempConvMode = ConvMode.HV,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        """
+        Applies Gaussian blur to a clip from an intuitive radius.
+
+        Args:
+            clip: Source clip.
+            radius: Size of the kernel in each direction. Automatically determined if not specified.
+            mode: Convolution mode (horizontal, vertical, both, or temporal). Defaults to HV.
+            planes: Planes to process. Defaults to all.
+            **kwargs: Additional arguments passed to the resizer or blur kernel. Specifying `_fast=True` enables fast
+                approximation.
+
+        Returns:
+            Blurred clip.
+        """
+        return gauss_blur(clip, [gauss_blur.get_sigma(r) for r in to_arr(radius)], None, mode, planes, **kwargs)
+
+    @staticmethod
+    def get_radius(sigma: float) -> int:
+        """
+        Compute the radius required for a given sigma value.
+
+        Args:
+            sigma: Gaussian sigma value.
+
+        Returns:
+            Radius.
+        """
+        return BlurMatrix.GAUSS.get_radius(sigma)
+
+
+@GaussBlur
 def gauss_blur(
     clip: vs.VideoNode,
     sigma: float | Sequence[float] = 0.5,
-    taps: int | None = None,
+    radius: int | None = None,
     mode: OneDimConvMode | TempConvMode = ConvMode.HV,
     planes: Planes = None,
     **kwargs: Any,
@@ -144,7 +214,7 @@ def gauss_blur(
     Args:
         clip: Source clip.
         sigma: Standard deviation of the Gaussian kernel. Can be a float or a list for per-plane control.
-        taps: Number of taps in the kernel. Automatically determined if not specified.
+        radius: Size of the kernel in each direction. Automatically determined if not specified.
         mode: Convolution mode (horizontal, vertical, both, or temporal). Defaults to HV.
         planes: Planes to process. Defaults to all.
         **kwargs: Additional arguments passed to the resizer or blur kernel. Specifying `_fast=True` enables fast
@@ -164,12 +234,14 @@ def gauss_blur(
         raise CustomValueError("Invalid mode specified", gauss_blur, mode)
 
     if isinstance(sigma, Sequence):
-        return normalize_radius(clip, gauss_blur, {"sigma": sigma}, planes, mode=mode)
+        return normalize_radius(clip, gauss_blur, {"sigma": sigma}, planes, radius=radius, mode=mode)
 
     fast = kwargs.pop("_fast", False)
 
     sigma_constant = 0.9 if fast and not mode.is_temporal else sigma
-    taps = BlurMatrix.GAUSS.get_taps(sigma_constant, taps)
+
+    if radius is None:
+        radius = gauss_blur.get_radius(sigma_constant)
 
     if not mode.is_temporal:
 
@@ -197,11 +269,11 @@ def gauss_blur(
             return Gaussian(sigma, taps).scale(plane, **resize_kwargs | kwargs)  # type: ignore[return-value]
 
         if not {*range(clip.format.num_planes)} - {*planes}:
-            return _resize2_blur(clip, sigma, taps)
+            return _resize2_blur(clip, sigma, radius)
 
-        return join([_resize2_blur(p, sigma, taps) if i in planes else p for i, p in enumerate(split(clip))])
+        return join([_resize2_blur(p, sigma, radius) if i in planes else p for i, p in enumerate(split(clip))])
 
-    kernel = BlurMatrix.GAUSS(taps, sigma=sigma, mode=mode, scale_value=1023)
+    kernel = BlurMatrix.GAUSS(radius, sigma=sigma, mode=mode, scale_value=1023)
 
     return kernel(clip, planes, **kwargs)
 
@@ -244,7 +316,7 @@ def min_blur(
 
     mode_blur, mode_median = normalize_seq(mode, 2)
 
-    blurred = BlurMatrix.BINOMIAL(radius=radius, mode=mode_blur)(clip, planes=planes, **kwargs)
+    blurred = BlurMatrix.BINOMIAL(radius, mode=mode_blur)(clip, planes=planes, **kwargs)
     median = median_blur(clip, radius, mode_median, planes=planes)
 
     return MeanMode.MEDIAN([clip, blurred, median], planes=planes)
@@ -279,6 +351,7 @@ def sbr(
         blur: Blur kernel to apply to the original clip. Defaults to binomial.
         blur_diff: Blur kernel to apply to the difference clip. Defaults to binomial.
         planes: Which planes to process. Defaults to all.
+        func: Function returned for custom error handling. This should only be set by VS package developers.
         **kwargs: Additional arguments passed to blur kernel call.
 
     Returns:
@@ -294,7 +367,7 @@ def sbr(
             return BlurMatrix.custom(blur, mode)(clip, planes, **kwargs)
 
         if isinstance(blur, BlurMatrix):
-            return blur(taps=radius, mode=mode)(clip, planes, **kwargs)
+            return blur(radius, mode=mode)(clip, planes, **kwargs)
 
         blurred = blur(clip) if callable(blur) else blur
 
@@ -325,6 +398,8 @@ def median_blur(
     radius: int | Sequence[int] = 1,
     mode: SpatialConvMode = ConvMode.SQUARE,
     planes: Planes = None,
+    *,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode: ...
 
 
@@ -337,12 +412,20 @@ def median_blur(
     smart: Literal[True] = ...,
     threshold: float | Sequence[float] | None = None,
     scalep: bool = True,
+    *,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode: ...
 
 
 @overload
 def median_blur(
-    clip: vs.VideoNode, radius: int = 1, mode: Literal[ConvMode.TEMPORAL] = ..., planes: Planes = None
+    clip: vs.VideoNode,
+    radius: int = 1,
+    mode: Literal[ConvMode.TEMPORAL] = ...,
+    planes: Planes = None,
+    *,
+    scenechange: bool = False,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode: ...
 
 
@@ -355,6 +438,8 @@ def median_blur(
     smart: bool = False,
     threshold: float | Sequence[float] | None = None,
     scalep: bool = True,
+    scenechange: bool = False,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode: ...
 
 
@@ -366,6 +451,8 @@ def median_blur(
     smart: bool = False,
     threshold: float | Sequence[float] | None = None,
     scalep: bool = True,
+    scenechange: bool = False,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode:
     """
     Applies a median blur to the clip using spatial or temporal neighborhood.
@@ -384,6 +471,9 @@ def median_blur(
             and over the threshold are returned as is.
         scalep: Parameter scaling when ``smart=True``. If True, all threshold values will be automatically scaled
             from 8-bit range (0-255) to the corresponding range of the input clip's bit depth.
+        scenechange: If True, avoid averaging frames over scene changes.
+            The user must first invoke [sc_detect][vstools.sc_detect].
+        func: Function returned for custom error handling. This should only be set by VS package developers.
 
     Raises:
         CustomValueError: If a list is passed for radius in temporal mode, which is unsupported
@@ -392,13 +482,48 @@ def median_blur(
     Returns:
         Median-blurred video clip.
     """
-    assert check_variable(clip, median_blur)
+    func = func or median_blur
+
+    assert check_variable(clip, func)
 
     if mode == ConvMode.TEMPORAL:
-        if isinstance(radius, int):
-            return clip.zsmooth.TemporalMedian(radius, planes)
+        if not isinstance(radius, int):
+            raise CustomValueError("A list of radius isn't supported for ConvMode.TEMPORAL!", func, radius)
 
-        raise CustomValueError("A list of radius isn't supported for ConvMode.TEMPORAL!", median_blur, radius)
+        tmedian = core.zsmooth.TemporalMedian(clip, radius, planes)
+
+        if not scenechange:
+            return tmedian
+
+        clips = shift_clip_multi(clip, (-radius, radius))
+        r = radius
+
+        def median_scenechange(
+            n: int, f: list[vs.VideoFrame], tmedian: vs.VideoNode, clips: Sequence[vs.VideoNode]
+        ) -> vs.VideoNode:
+            backwards_prop = [get_prop(frame, "_SceneChangeNext", int) for frame in f[:r]]
+            forward_prop = [get_prop(frame, "_SceneChangePrev", int) for frame in f[r + 1 :]]
+
+            if not any([*backwards_prop, *forward_prop]):
+                return tmedian
+
+            clips_back = clips[:r]
+
+            for i, prop in enumerate(reversed(backwards_prop)):
+                if prop:
+                    clips_back = clips_back[r - i :]
+                    break
+
+            clips_forw = clips[r + 1 :]
+
+            for i, prop in enumerate(forward_prop):
+                if prop:
+                    clips_forw = clips_forw[: i - r]
+                    break
+
+            return MeanMode.MEDIAN(clips[r], clips_back, clips_forw, planes=planes)
+
+        return core.std.FrameEval(clip, lambda n, f: median_scenechange(n, f, tmedian, clips), clips, clips)
 
     radius = normalize_seq(radius, clip.format.num_planes)
 
@@ -406,7 +531,7 @@ def median_blur(
         if mode == ConvMode.SQUARE:
             return core.zsmooth.SmartMedian(clip, radius, threshold, scalep, planes)
 
-        raise CustomValueError("When using SmartMedian, mode should be ConvMode.SQUARE!", median_blur, mode)
+        raise CustomValueError("When using SmartMedian, mode should be ConvMode.SQUARE!", func, mode)
 
     if mode == ConvMode.SQUARE and max(radius) <= 3:
         return core.zsmooth.Median(clip, radius, planes)
@@ -414,23 +539,7 @@ def median_blur(
     if mode == ConvMode.VERTICAL and max(radius) <= 1:
         return vertical_cleaner(clip, radius, planes)
 
-    expr_plane = list[list[str]]()
-
-    for r in radius:
-        expr_passes = list[str]()
-
-        for mat in ExprOp.matrix("x", r, mode):
-            n_samples = len(mat)
-            n_op = n_samples // 2
-
-            expr_passes.append(f"{mat} sort{n_samples} drop{n_op} swap{n_op} drop{n_op}")
-
-        expr_plane.append(expr_passes)
-
-    for e in zip(*expr_plane):
-        clip = norm_expr(clip, e, planes, func=median_blur)
-
-    return clip
+    return MeanMode.MEDIAN.single(clip, radius, mode, planes=planes, func=func)
 
 
 class Bilateral(Generic[P, R]):
@@ -504,9 +613,10 @@ def bilateral(
         ```
 
     For more details, see:
-        - https://github.com/dnjulek/vapoursynth-zip/wiki/Bilateral
-        - https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Bilateral
-        - https://github.com/WolframRhodium/VapourSynth-BilateralGPU
+
+      - <https://github.com/dnjulek/vapoursynth-zip/wiki/Bilateral>
+      - <https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Bilateral>
+      - <https://github.com/WolframRhodium/VapourSynth-BilateralGPU>
 
     Args:
         clip: Source clip.
