@@ -275,23 +275,23 @@ class BlurMatrix(CustomEnum):
 
     @overload
     def __call__(  # type: ignore[misc]
-        self: Literal[BlurMatrix.MEAN_NO_CENTER], taps: int = 1, *, mode: ConvMode = ConvMode.SQUARE
+        self: Literal[BlurMatrix.MEAN_NO_CENTER], radius: int = 1, *, mode: ConvMode = ConvMode.SQUARE
     ) -> BlurMatrixBase[int]: ...
 
     @overload
     def __call__(  # type: ignore[misc]
-        self: Literal[BlurMatrix.MEAN], taps: int = 1, *, mode: ConvMode = ConvMode.SQUARE
+        self: Literal[BlurMatrix.MEAN], radius: int = 1, *, mode: ConvMode = ConvMode.SQUARE
     ) -> BlurMatrixBase[int]: ...
 
     @overload
     def __call__(  # type: ignore[misc]
-        self: Literal[BlurMatrix.BINOMIAL], taps: int = 1, *, mode: ConvMode = ConvMode.HV
+        self: Literal[BlurMatrix.BINOMIAL], radius: int = 1, *, mode: ConvMode = ConvMode.HV
     ) -> BlurMatrixBase[int]: ...
 
     @overload
     def __call__(  # type: ignore[misc]
         self: Literal[BlurMatrix.GAUSS],
-        taps: int | None = None,
+        radius: int | None = None,
         *,
         sigma: float = 0.5,
         mode: ConvMode = ConvMode.HV,
@@ -299,16 +299,18 @@ class BlurMatrix(CustomEnum):
     ) -> BlurMatrixBase[float]: ...
 
     @overload
-    def __call__(self, taps: int | None = None, **kwargs: Any) -> Any: ...
+    def __call__(self, radius: int | None = None, **kwargs: Any) -> BlurMatrixBase[Any]: ...
 
-    def __call__(self, taps: int | None = None, **kwargs: Any) -> Any:
+    def __call__(self, radius: int | None = None, **kwargs: Any) -> Any:
         """
         Generate the blur kernel based on the enum variant.
 
         Args:
-            taps: Size of the kernel in each direction.
-            sigma: [GAUSS only] Standard deviation of the Gaussian kernel.
-            mode: Convolution mode. Default depends on kernel.
+            radius: Size of the kernel in each direction.
+            **kwargs: Additional keywords arguments:
+
+                   - sigma: [GAUSS only] Standard deviation of the Gaussian kernel.
+                   - mode: Convolution mode. Default depends on kernel.
 
         Returns:
             A `BlurMatrixBase` instance representing the kernel.
@@ -317,37 +319,36 @@ class BlurMatrix(CustomEnum):
 
         match self:
             case BlurMatrix.MEAN_NO_CENTER:
-                taps = fallback(taps, 1)
+                radius = fallback(radius, 1)
                 mode = kwargs.pop("mode", ConvMode.SQUARE)
 
-                matrix = [1 for _ in range(((2 * taps + 1) ** (2 if mode == ConvMode.SQUARE else 1)) - 1)]
+                matrix = [1 for _ in range(((2 * radius + 1) ** (2 if mode == ConvMode.SQUARE else 1)) - 1)]
                 matrix.insert(len(matrix) // 2, 0)
 
                 return self.custom(matrix, mode)
 
             case BlurMatrix.MEAN:
-                taps = fallback(taps, 1)
+                radius = fallback(radius, 1)
                 mode = kwargs.pop("mode", ConvMode.SQUARE)
 
-                kernel = self.custom((1 for _ in range((2 * taps + 1))), mode)
+                kernel = self.custom((1 for _ in range((2 * radius + 1))), mode)
 
             case BlurMatrix.BINOMIAL:
-                taps = fallback(taps, 1)
+                radius = fallback(radius, 1)
                 mode = kwargs.pop("mode", ConvMode.HV)
 
                 c = 1
-                n = taps * 2 + 1
+                n = radius * 2 + 1
 
                 matrix = list[int]()
 
-                for i in range(1, taps + 2):
+                for i in range(1, radius + 2):
                     matrix.append(c)
                     c = c * (n - i) // i
 
                 kernel = self.custom(matrix[:-1] + matrix[::-1], mode)
 
             case BlurMatrix.GAUSS:
-                taps = fallback(taps, 1)
                 sigma = kwargs.pop("sigma", 0.5)
                 mode = kwargs.pop("mode", ConvMode.HV)
                 scale_value = kwargs.pop("scale_value", 1023)
@@ -355,16 +356,14 @@ class BlurMatrix(CustomEnum):
                 if mode == ConvMode.SQUARE:
                     scale_value = sqrt(scale_value)
 
-                taps = self.get_taps(sigma, taps)
-
-                if taps < 0:
-                    raise CustomValueError("Taps must be >= 0!")
+                if radius is None:
+                    radius = self.get_radius(sigma)
 
                 if sigma > 0.0:
                     half_pisqrt = 1.0 / sqrt(2.0 * pi) * sigma
                     doub_qsigma = 2 * sigma**2
 
-                    high, *mat = [half_pisqrt * exp(-(x**2) / doub_qsigma) for x in range(taps + 1)]
+                    high, *mat = [half_pisqrt * exp(-(x**2) / doub_qsigma) for x in range(radius + 1)]
 
                     mat = [x * scale_value / high for x in mat]
                     mat = [*mat[::-1], scale_value, *mat]
@@ -381,6 +380,22 @@ class BlurMatrix(CustomEnum):
 
         return kernel
 
+    def get_sigma(self: Literal[BlurMatrix.GAUSS], radius: int) -> float:  # type: ignore[misc]
+        """
+        Generate a Gaussian sigma value from an intuitive radius.
+
+        This is a shortcut that converts a blur radius to a corresponding sigma value.
+
+        Args:
+            radius: Blur radius.
+
+        Returns:
+            Gaussian sigma value
+        """
+        assert self is BlurMatrix.GAUSS
+
+        return radius / 3
+
     def from_radius(self: Literal[BlurMatrix.GAUSS], radius: int) -> BlurMatrixBase[float]:  # type: ignore[misc]
         """
         Generate a Gaussian blur kernel from an intuitive radius.
@@ -395,25 +410,21 @@ class BlurMatrix(CustomEnum):
         """
         assert self is BlurMatrix.GAUSS
 
-        return BlurMatrix.GAUSS(None, sigma=(radius + 1.0) / 3)
+        return BlurMatrix.GAUSS(None, sigma=self.get_sigma(radius))
 
-    def get_taps(self: Literal[BlurMatrix.GAUSS], sigma: float, taps: int | None = None) -> int:  # type: ignore[misc]
+    def get_radius(self: Literal[BlurMatrix.GAUSS], sigma: float) -> int:  # type: ignore[misc]
         """
-        Compute the number of taps required for a given sigma value.
+        Compute the radius required for a given sigma value.
 
         Args:
             sigma: Gaussian sigma value.
-            taps: Optional manual override; if not provided, it's computed from sigma.
 
         Returns:
-            Number of taps.
+            Radius.
         """
         assert self is BlurMatrix.GAUSS
 
-        if taps is None:
-            taps = ceil(abs(sigma) * 8 + 1) // 2
-
-        return taps
+        return ceil(sigma * 6 + 1) // 2
 
     @classmethod
     def custom(cls, values: Iterable[_Nb], mode: ConvMode = ConvMode.SQUARE) -> BlurMatrixBase[_Nb]:
