@@ -4,9 +4,10 @@ This module implements scalers for ONNX models.
 
 from __future__ import annotations
 
+import re
 from abc import ABC
 from dataclasses import Field, asdict, fields, replace
-from importlib.util import find_spec
+from functools import cache
 from logging import DEBUG, debug, getLogger, warning
 from typing import (
     TYPE_CHECKING,
@@ -22,6 +23,7 @@ from typing import (
 )
 
 from jetpytools import CustomImportError
+from packaging.version import Version
 from typing_extensions import Self, deprecated
 
 from vsexprtools import norm_expr
@@ -33,6 +35,7 @@ from vstools import (
     DitherType,
     Matrix,
     MatrixLike,
+    OutdatedPluginError,
     ProcessVariableResClip,
     SPath,
     SPathLike,
@@ -50,21 +53,6 @@ from vstools import (
     vs,
 )
 
-if TYPE_CHECKING:
-    from vsmlrt import backendT as Backend
-
-    BackendLike = Backend | type[Backend] | str
-    """
-    Type alias for anything that can resolve to a Backend from vs-mlrt.
-
-    This includes:
-    - A string identifier.
-    - A class type subclassing `Backend`.
-    - An instance of a `Backend`.
-    """
-else:
-    BackendLike = Any
-
 from .generic import BaseGenericScaler
 
 __all__ = [
@@ -95,6 +83,89 @@ def _get_backend_fields(backend: Any) -> dict[str, Field[Any]]:
     return {f.name: f for f in fields(backend)}
 
 
+if TYPE_CHECKING:
+    from vsmlrt import backendT as Backend
+
+    BackendLike = Backend | type[Backend] | str
+    """
+    Type alias for anything that can resolve to a Backend from vs-mlrt.
+
+    This includes:
+    - A string identifier.
+    - A class type subclassing `Backend`.
+    - An instance of a `Backend`.
+    """
+else:
+    BackendLike = Any
+
+
+def _normalize_git_version(raw: str) -> Version:
+    raw = raw.strip().lstrip("v")
+
+    matched = re.match(r"(?P<tag>[0-9A-Za-z.\-_]+?)(?:-(?P<count>\d+)-g(?P<hash>[0-9a-f]+))?$", raw)
+
+    if not matched:
+        raise ValueError(f"Unrecognized git-describe string: {raw!r}")
+
+    tag = matched.group("tag")
+    count = int(matched.group("count") or 0)
+
+    tag_parts = tag.split(".", 2)
+    numeric_parts = list[str]()
+    suffix_parts = list[str]()
+
+    for part in tag_parts:
+        if part.isdigit():
+            numeric_parts.append(part)
+        else:
+            suffix_parts.append(part)
+
+    base_version = ".".join(numeric_parts)
+    normalized = base_version if count == 0 else f"{base_version}.post{count}"
+
+    local_segments = list[str]()
+
+    if suffix_parts:
+        local_segments.append(".".join(suffix_parts))
+
+    if local_segments:
+        normalized += "+" + ".".join(local_segments)
+
+    return Version(normalized)
+
+
+@cache
+def _check_vsmlrt_script_version(cls: type[BaseOnnxScaler]) -> None:
+    try:
+        import vsmlrt
+    except ImportError:
+        raise CustomImportError(cls, "vsmlrt") from None
+
+    if (current_version := Version(vsmlrt.__version__)) < cls._REQUIRED_VSMLRT_SCRIPT_VERSION:
+        raise CustomImportError(
+            cls,
+            "vsmlrt",
+            f"Detected vs-mlrt version {current_version} is older than {cls._REQUIRED_VSMLRT_SCRIPT_VERSION}. "
+            "Please update to a more recent version.",
+        )
+
+
+@cache
+def _check_vsmlrt_plugin_version(backend_name: str, cls: type[BaseOnnxScaler]) -> None:
+    bname = backend_name.lower().split("_", 1)
+    plugin_name = "trt_rtx" if bname == ["trt", "rtx"] else bname[0]
+
+    current_version = _normalize_git_version(getattr(core, plugin_name).Version()["version"].decode())
+
+    if current_version < cls._REQUIRED_VSMLRT_PLUGIN_VERSION:
+        raise OutdatedPluginError(
+            cls,
+            plugin_name,
+            f"The plugin '{plugin_name}' version is older than {cls._REQUIRED_VSMLRT_PLUGIN_VERSION}. "
+            "Please update to a more recent version.",
+        )
+
+
 def autoselect_backend(**kwargs: Any) -> Backend:
     """
     Try to select the best backend for the current system.
@@ -147,11 +218,14 @@ class BaseOnnxScaler(BaseGenericScaler, ABC):
     Abstract generic scaler class for an ONNX model.
     """
 
-    def __new__(cls, *args: Any, **kwargs: Any) -> Self:
-        if find_spec("vsmlrt") is None:
-            raise CustomImportError(cls, "vsmlrt")
+    _REQUIRED_VSMLRT_SCRIPT_VERSION = Version("3.22.35")
+    _REQUIRED_VSMLRT_PLUGIN_VERSION = Version("15.13")
 
-        return super().__new__(cls, *args, **kwargs)
+    if not TYPE_CHECKING:
+
+        def __new__(cls, *args: Any, **kwargs: Any) -> Self:
+            _check_vsmlrt_script_version(cls)
+            return super().__new__(cls, *args, **kwargs)
 
     def __init__(
         self,
@@ -212,6 +286,8 @@ class BaseOnnxScaler(BaseGenericScaler, ABC):
         else:
             self.backend = replace(backend, **_clean_keywords(self.kwargs, backend))
 
+        _check_vsmlrt_plugin_version(self.backend.__class__.__name__, self.__class__)
+
         self.tiles = tiles
         self.tilesize = tilesize
         self.overlap = overlap
@@ -391,7 +467,15 @@ class BaseOnnxScaler(BaseGenericScaler, ABC):
             if (isinstance(self.backend, _SupportsFP16) and self.backend.fp16)
             and isinstance(
                 self.backend,
-                (Backend.TRT, Backend.TRT_RTX, Backend.ORT_CPU, Backend.ORT_CUDA, Backend.ORT_DML, Backend.ORT_COREML),
+                (
+                    Backend.TRT,
+                    Backend.TRT_RTX,
+                    Backend.ORT_CPU,
+                    Backend.ORT_CUDA,
+                    Backend.ORT_DML,
+                    Backend.ORT_COREML,
+                    Backend.NCNN_VK,
+                ),
             )
             else fp32
         )
@@ -401,6 +485,33 @@ class BaseOnnxScaler(BaseGenericScaler, ABC):
         return precision
 
 
+class BaseOnnxScalerRGB(BaseOnnxScaler):
+    """
+    Abstract ONNX class for RGB models.
+    """
+
+    def preprocess_clip(self, clip: vs.VideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
+        clip = self.kernel.resample(clip, self._pick_precision(vs.RGBH, vs.RGBS), Matrix.RGB, **kwargs)
+        return limiter(clip, func=self.__class__)
+
+    def postprocess_clip(self, clip: vs.VideoNode, input_clip: vs.VideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
+        assert check_variable_format(clip, self.__class__)
+
+        if get_video_format(clip) != get_video_format(input_clip):
+            kwargs = (
+                dict[str, Any](
+                    format=input_clip,
+                    matrix=Matrix.from_video(input_clip, func=self.__class__),
+                    range=ColorRange.from_video(input_clip, func=self.__class__),
+                    dither_type=DitherType.ORDERED,
+                )
+                | kwargs
+            )
+            clip = self.kernel.resample(clip, **kwargs)
+
+        return clip
+
+
 class GenericOnnxScaler(BaseOnnxScaler, partial_abstract=True):
     """
     Generic scaler class for an ONNX model.
@@ -603,6 +714,51 @@ class ArtCNN(BaseArtCNNLuma):
 
     _model = 7
 
+    class C4F16(BaseArtCNNLuma):
+        """
+        This has 4 internal convolution layers with 16 filters each.
+
+        The currently fastest variant. Not really recommended for any filtering.
+        Should strictly be used for real-time applications and even then the other non R ones should be fast enough...
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        doubled = ArtCNN.C4F16().scale(clip, clip.width * 2, clip.height * 2)
+        ```
+        """
+
+        _model = 10
+
+    class C4F16_DN(BaseArtCNNLuma):  # noqa: N801
+        """
+        The same as C4F16 but intended to also denoise. Works well on noisy sources when you don't want any sharpening.
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        doubled = ArtCNN.C4F16_DN().scale(clip, clip.width * 2, clip.height * 2)
+        ```
+        """
+
+        _model = 13
+
+    class C4F16_DS(BaseArtCNNLuma):  # noqa: N801
+        """
+        The same as C4F16 but intended to also denoise and sharpen.
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        doubled = ArtCNN.C4F16_DS().scale(clip, clip.width * 2, clip.height * 2)
+        ```
+        """
+
+        _model = 11
+
     class C4F32(BaseArtCNNLuma):
         """
         This has 4 internal convolution layers with 32 filters each.
@@ -619,9 +775,43 @@ class ArtCNN(BaseArtCNNLuma):
 
         _model = 0
 
+    @deprecated(
+        "This model is no longer maintained and has been deprecated. Please use R8F64_Chroma instead.",
+        category=DeprecationWarning,
+    )
+    class C4F32_Chroma(BaseArtCNNChroma):  # noqa: N801
+        """
+        The smaller of the chroma models.
+
+        These don't double the input clip and rather just try to enhance the chroma using luma information.
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        chroma_upscaled = ArtCNN.C4F32_Chroma().scale(clip)
+        ```
+        """
+
+        _model = 4
+
+    class C4F32_DN(BaseArtCNNLuma):  # noqa: N801
+        """
+        The same as C4F32 but intended to also denoise. Works well on noisy sources when you don't want any sharpening.
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        doubled = ArtCNN.C4F32_DN().scale(clip, clip.width * 2, clip.height * 2)
+        ```
+        """
+
+        _model = 14
+
     class C4F32_DS(BaseArtCNNLuma):  # noqa: N801
         """
-        The same as C4F32 but intended to also sharpen and denoise.
+        The same as C4F32 but intended to also denoise and sharpen.
 
         Example usage:
         ```py
@@ -656,46 +846,12 @@ class ArtCNN(BaseArtCNNLuma):
         _model = 2
 
     @deprecated(
-        "This model is no longer maintained and has been deprecated. Please use R8F64 instead.",
-        category=DeprecationWarning,
-    )
-    class C16F64_DS(BaseArtCNNLuma):  # noqa: N801
-        """
-        The same as C16F64 but intended to also sharpen and denoise.
-
-        Example usage:
-        ```py
-        from vsscale import ArtCNN
-
-        doubled = ArtCNN.C16F64_DS().scale(clip, clip.width * 2, clip.height * 2)
-        ```
-        """
-
-        _model = 3
-
-    class C4F32_Chroma(BaseArtCNNChroma):  # noqa: N801
-        """
-        The smaller of the two chroma models.
-
-        These don't double the input clip and rather just try to enhance the chroma using luma information.
-
-        Example usage:
-        ```py
-        from vsscale import ArtCNN
-
-        chroma_upscaled = ArtCNN.C4F32_Chroma().scale(clip)
-        ```
-        """
-
-        _model = 4
-
-    @deprecated(
-        "This model is no longer maintained and has been deprecated. Please use R8F64 instead.",
+        "This model is no longer maintained and has been deprecated. Please use R8F64_Chroma instead.",
         category=DeprecationWarning,
     )
     class C16F64_Chroma(BaseArtCNNChroma):  # noqa: N801
         """
-        The bigger of the two chroma models.
+        The bigger of the old chroma models.
 
         These don't double the input clip and rather just try to enhance the chroma using luma information.
 
@@ -709,21 +865,23 @@ class ArtCNN(BaseArtCNNLuma):
 
         _model = 5
 
-    class R16F96(BaseArtCNNLuma):
+    @deprecated(
+        "This model is no longer maintained and has been deprecated. Please use R8F64 instead.",
+        category=DeprecationWarning,
+    )
+    class C16F64_DS(BaseArtCNNLuma):  # noqa: N801
         """
-        The biggest model. Can compete with or outperform Waifu2x Cunet.
-
-        Also quite a bit slower but is less heavy on vram.
+        The same as C16F64 but intended to also denoise and sharpen.
 
         Example usage:
         ```py
         from vsscale import ArtCNN
 
-        doubled = ArtCNN.R16F96().scale(clip, clip.width * 2, clip.height * 2)
+        doubled = ArtCNN.C16F64_DS().scale(clip, clip.width * 2, clip.height * 2)
         ```
         """
 
-        _model = 6
+        _model = 3
 
     class R8F64(BaseArtCNNLuma):
         """
@@ -739,20 +897,6 @@ class ArtCNN(BaseArtCNNLuma):
 
         _model = 7
 
-    class R8F64_DS(BaseArtCNNLuma):  # noqa: N801
-        """
-        The same as R8F64 but intended to also sharpen and denoise.
-
-        Example usage:
-        ```py
-        from vsscale import ArtCNN
-
-        doubled = ArtCNN.R8F64_DS().scale(clip, clip.width * 2, clip.height * 2)
-        ```
-        """
-
-        _model = 8
-
     class R8F64_Chroma(BaseArtCNNChroma):  # noqa: N801
         """
         The new and fancy big chroma model.
@@ -769,36 +913,63 @@ class ArtCNN(BaseArtCNNLuma):
 
         _model = 9
 
-    class C4F16(BaseArtCNNLuma):
+    class R8F64_DS(BaseArtCNNLuma):  # noqa: N801
         """
-        This has 4 internal convolution layers with 16 filters each.
-
-        The currently fastest variant. Not really recommended for any filtering.
-        Should strictly be used for real-time applications and even then the other non R ones should be fast enough...
+        The same as R8F64 but intended to also denoise and sharpen.
 
         Example usage:
         ```py
         from vsscale import ArtCNN
 
-        doubled = ArtCNN.C4F16().scale(clip, clip.width * 2, clip.height * 2)
+        doubled = ArtCNN.R8F64_DS().scale(clip, clip.width * 2, clip.height * 2)
         ```
         """
 
-        _model = 10
+        _model = 8
 
-    class C4F16_DS(BaseArtCNNLuma):  # noqa: N801
+    class R8F64_JPEG420(BaseArtCNN, BaseOnnxScalerRGB):  # noqa: N801
         """
-        The same as C4F16 but intended to also sharpen and denoise.
+        1x RGB model meant to clean JPEG artifacts and to fix chroma subsampling.
 
         Example usage:
         ```py
         from vsscale import ArtCNN
 
-        doubled = ArtCNN.C4F16_DS().scale(clip, clip.width * 2, clip.height * 2)
+        doubled = ArtCNN.R8F64_JPEG420().scale(clip)
         ```
         """
 
-        _model = 11
+        _model = 15
+
+    class R8F64_JPEG444(BaseArtCNN, BaseOnnxScalerRGB):  # noqa: N801
+        """
+        1x RGB model meant to clean JPEG artifacts.
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        doubled = ArtCNN.R8F64_JPEG444().scale(clip)
+        ```
+        """
+
+        _model = 16
+
+    class R16F96(BaseArtCNNLuma):
+        """
+        The biggest model. Can compete with or outperform Waifu2x Cunet.
+
+        Also quite a bit slower but is less heavy on vram.
+
+        Example usage:
+        ```py
+        from vsscale import ArtCNN
+
+        doubled = ArtCNN.R16F96().scale(clip, clip.width * 2, clip.height * 2)
+        ```
+        """
+
+        _model = 6
 
     class R16F96_Chroma(BaseArtCNNChroma):  # noqa: N801
         """
@@ -893,30 +1064,7 @@ class BaseWaifu2x(BaseOnnxScaler):
         )
 
 
-class BaseWaifu2xRGB(BaseWaifu2x):
-    def preprocess_clip(self, clip: vs.VideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
-        clip = self.kernel.resample(clip, self._pick_precision(vs.RGBH, vs.RGBS), Matrix.RGB, **kwargs)
-        return limiter(clip, func=self.__class__)
-
-    def postprocess_clip(self, clip: vs.VideoNode, input_clip: vs.VideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
-        assert check_variable_format(clip, self.__class__)
-
-        if get_video_format(clip) != get_video_format(input_clip):
-            kwargs = (
-                dict[str, Any](
-                    format=input_clip,
-                    matrix=Matrix.from_video(input_clip, func=self.__class__),
-                    range=ColorRange.from_video(input_clip, func=self.__class__),
-                    dither_type=DitherType.ORDERED,
-                )
-                | kwargs
-            )
-            clip = self.kernel.resample(clip, **kwargs)
-
-        return clip
-
-
-class _Waifu2xCunet(BaseWaifu2xRGB):
+class _Waifu2xCunet(BaseWaifu2x, BaseOnnxScalerRGB):
     _model = 6
     _static_kernel_radius = 16
 
@@ -1013,7 +1161,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 0
 
-    class AnimeStyleArtRGB(BaseWaifu2xRGB):
+    class AnimeStyleArtRGB(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         RGB version of the anime-style model.
 
@@ -1027,7 +1175,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 1
 
-    class Photo(BaseWaifu2xRGB):
+    class Photo(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         Waifu2x model trained on real-world photographic images.
 
@@ -1041,7 +1189,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 2
 
-    class UpConv7AnimeStyleArt(BaseWaifu2xRGB):
+    class UpConv7AnimeStyleArt(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         UpConv7 model variant optimized for anime-style images.
 
@@ -1055,7 +1203,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 3
 
-    class UpConv7Photo(BaseWaifu2xRGB):
+    class UpConv7Photo(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         UpConv7 model variant optimized for photographic images.
 
@@ -1069,7 +1217,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 4
 
-    class UpResNet10(BaseWaifu2xRGB):
+    class UpResNet10(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         UpResNet10 model offering a balance of speed and quality.
 
@@ -1095,7 +1243,7 @@ class Waifu2x(_Waifu2xCunet):
         ```
         """
 
-    class SwinUnetArt(BaseWaifu2xRGB):
+    class SwinUnetArt(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         Swin-Unet-based model trained on anime-style images.
 
@@ -1109,7 +1257,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 7
 
-    class SwinUnetPhoto(BaseWaifu2xRGB):
+    class SwinUnetPhoto(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         Swin-Unet model trained on photographic content.
 
@@ -1123,7 +1271,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 8
 
-    class SwinUnetPhotoV2(BaseWaifu2xRGB):
+    class SwinUnetPhotoV2(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         Improved Swin-Unet model for photos (v2).
 
@@ -1137,7 +1285,7 @@ class Waifu2x(_Waifu2xCunet):
 
         _model = 9
 
-    class SwinUnetArtScan(BaseWaifu2xRGB):
+    class SwinUnetArtScan(BaseWaifu2x, BaseOnnxScalerRGB):
         """
         Swin-Unet model trained on anime scans.
 
